<?php

namespace FiloBlu\Rma\Observer;

use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;

/**
 * RMA observer
 *
 * @author      Magento Core Team <core@magentocommerce.com>
 */
class RmaSaveAfterObserver implements ObserverInterface
{


    /**
     * RmaSaveAfterObserver constructor.
     * @param \Magento\Eav\Model\Config $eav_config
     * @param \FiloBlu\Rma\Api\Model\Config\Reader $reader
     * @param \Magento\Rma\Api\Data\RmaInterface $rmaInterface
     */
    public function __construct(        
        \Magento\Eav\Model\Config $eav_config,
        \FiloBlu\Rma\Api\Model\Config\Reader $reader,
        \Magento\Rma\Api\Data\RmaInterface $rmaInterface
    ) {
        $this->eav_config = $eav_config;
        $this->reader = $reader;
        $this->_rmaInterface = $rmaInterface;
    }
    

    /**
     * Check reason and status for each RMA item. Depending on reason, change RMA item status.
     *
     * @param EventObserver $observer
     * @return void
     */
    public function execute(EventObserver $observer)
    {
        
        error_log(__METHOD__);
        /** @var $rma \FiloBlu\Rma\Model\Rma */
        $rma = $observer->getEvent()->getRma();
        
        $collection = $rma->getItems();
        $standard_reasons_config = $this->reader->read();
        $_standard_reason_approval = array();
        foreach($standard_reasons_config as $reason):
            if($reason['automatic_approval']==1):
                $_standard_reason_approval[] = $reason['id']; 
            endif;
        endforeach;

        foreach ($collection as $item) {
            if ($item->getStatus() == \Magento\Rma\Model\Item\Attribute\Source\Status::STATE_PENDING
                && in_array($item->getReason(), $_standard_reason_approval) ) {
                  $item->setStatus(\Magento\Rma\Model\Item\Attribute\Source\Status::STATE_AUTHORIZED);
                  $item->save();
            }
        }
        return true;
    }

    
}


